@@ -36,7 +36,7 @@ import pyart
 from ..io.io_aux import get_datatype_fields, get_fieldname_pyart
 from ..io.io_aux import get_file_list
 from ..io.read_data_radar import interpol_field
-from ..io.read_data_other import read_rhi_profile
+from ..io.read_data_other import read_rhi_profile, read_vpr_theo_parameters
 
 from ..util.radar_utils import time_avg_range
 
@@ -867,6 +867,8 @@ def process_vpr(procstatus, dscfg, radar_list=None):
         h_max : float
             maximum altitude [masl] where to compute the model profile.
             Default 6000.
+        h_corr_max : float
+            maximum altitude [masl] considered for the VPR correction
         h_res : float
             resolution of the model profile (m). Default 1.
         max_weight : float
@@ -887,8 +889,21 @@ def process_vpr(procstatus, dscfg, radar_list=None):
             descriptor used get the linear reflectivity information
         vpr_theo_datatype : str
             descriptor used to get the retrieved theoretical VPR
+        filter_params : bool
+            If True the current theoretical VPR profile is averaged with the
+            past VPR profile by averaging the 4 parameters that define the
+            profile, otherwise the shape of the profiles is averaged. Default
+            false. Used only in non-spatialised VPR correction
         weight_mem : float
             Weight given to past VPR when filtering the current VPR
+        spatialized : bool
+            If True the VPR correction is spatialized
+        correct_iso0 : bool
+            If True the iso0 field is corrected by a bias constant computed as
+            the difference between the retrieved melting layer top and the
+            average iso0 and areas with precipitation. Default True. Used only
+            in the spatialised VPR correction
+
     radar_list : list of Radar objects
         Optional. list of radar objects
 
@@ -944,7 +959,6 @@ def process_vpr(procstatus, dscfg, radar_list=None):
         warn('ERROR: Unable to compute VPR. Missing data')
         return None, None
 
-    refl_corr = pyart.correct.correct_vpr(radar, refl_field=refl_field)
     # User defined variables
     nvalid_min = dscfg.get('nvalid_min', 20)
     angle_min = dscfg.get('angle_min', 0.)
@@ -964,7 +978,9 @@ def process_vpr(procstatus, dscfg, radar_list=None):
     dr_default = dscfg.get('dr_default', -4.5)
     dr_alt = dscfg.get('dr_alt', 800.)
     h_max = dscfg.get('h_max', 6000.)
+    h_corr_max = dscfg.get('h_corr_max', 15000.)
     h_res = dscfg.get('h_res', 1.)
+    filter_params = dscfg.get('filter_params', False)
     max_weight = dscfg.get('max_weight', 9.)
     rmin_obs = dscfg.get('rmin_obs', 5000.)
     rmax_obs = dscfg.get('rmax_obs', 150000.)
@@ -975,6 +991,8 @@ def process_vpr(procstatus, dscfg, radar_list=None):
     vpr_memory_max = dscfg.get('vpr_memory_max', 0.)
     filter_vpr_memory_max = dscfg.get('filter_vpr_memory_max', 0.)
     weight_mem = dscfg.get('weight_mem', 0.75)
+    spatialised = dscfg.get('spatialised', False)
+    correct_iso0 = dscfg.get('correct_iso0', True)
 
     iso0 = None
     if use_ml:
@@ -996,8 +1014,8 @@ def process_vpr(procstatus, dscfg, radar_list=None):
                     warn('Unable to use retrieved melting layer data')
                     iso0 = None
                 else:
-                    print('Using file {} with melting layer information'.format(
-                        flist[0]))
+                    print(f'Using file {flist[0]} '
+                          f'with melting layer information')
                     iso0 = np.ma.mean(
                         radar_ml.fields['melting_layer_height']['data'][:, 1])
                     ml_bottom = np.ma.mean(
@@ -1026,8 +1044,7 @@ def process_vpr(procstatus, dscfg, radar_list=None):
                     if radar_vpr is None:
                         warn('Unable to use azimuthal reflectivity average')
                         continue
-                    print('Using file {} with azimuthal averaged refl'.format(
-                          fname))
+                    print(f'Using file {fname} with azimuthal averaged refl')
                     radar_mem_list.append(radar_vpr)
                 if not radar_mem_list:
                     radar_mem_list = None
@@ -1047,30 +1064,55 @@ def process_vpr(procstatus, dscfg, radar_list=None):
             if not flist:
                 warn('unable to find files containing retrieved VPR')
             else:
-                height, _, vals = read_rhi_profile(flist[-1], labels=['Znorm'])
-                vpr_theo_dict_mem = {
-                    'value': vals[:, 0],
-                    'altitude': height}
-                print('Using file {} with previously retrieved VPR'.format(
-                      flist[-1]))
+                if spatialised or filter_params:
+                    # this function will read the stored VPR parameters from
+                    # the previous volume
+                    vpr_theo_dict_mem = read_vpr_theo_parameters(flist[-1])
+                else:
+                    height, _, vals = read_rhi_profile(
+                        flist[-1], labels=['Znorm'])
+                    vpr_theo_dict_mem = {
+                        'value': vals[:, 0],
+                        'altitude': height}
+                print(f'Using file {flist[-1]} with previously retrieved VPR')
 
     corr_refl_field = 'corrected_reflectivity'
     corr_field = 'vpr_correction'
-    refl_corr, vpr_corr, vpr_theo_dict, radar_rhi = pyart.correct.correct_vpr(
-        radar, nvalid_min=nvalid_min, angle_min=angle_min,
-        angle_max=angle_max, ml_thickness_min=ml_thickness_min,
-        ml_thickness_max=ml_thickness_max,
-        ml_thickness_step=ml_thickness_step, iso0_max=iso0_max,
-        ml_top_diff_max=ml_top_diff_max, ml_top_step=ml_top_step,
-        ml_peak_min=ml_peak_min, ml_peak_max=ml_peak_max,
-        ml_peak_step=ml_peak_step, dr_min=dr_min, dr_max=dr_max,
-        dr_step=dr_step, dr_default=dr_default, dr_alt=dr_alt, h_max=h_max,
-        h_res=h_res, max_weight=max_weight, rmin_obs=rmin_obs,
-        rmax_obs=rmax_obs, iso0=iso0, weight_mem=weight_mem,
-        vpr_theo_dict_mem=vpr_theo_dict_mem, radar_mem_list=radar_mem_list,
-        refl_field=refl_field, corr_refl_field=corr_refl_field,
-        corr_field=corr_field, temp_field=temp_field, iso0_field=iso0_field,
-        temp_ref=temp_ref)
+
+    if spatialised:
+        refl_corr, vpr_corr, vpr_theo_dict, radar_rhi, vpr_info = pyart.correct.correct_vpr_spatialised(
+            radar, nvalid_min=nvalid_min, angle_min=angle_min,
+            angle_max=angle_max, ml_thickness_min=ml_thickness_min,
+            ml_thickness_max=ml_thickness_max,
+            ml_thickness_step=ml_thickness_step, iso0_max=iso0_max,
+            ml_top_diff_max=ml_top_diff_max, ml_top_step=ml_top_step,
+            ml_peak_min=ml_peak_min, ml_peak_max=ml_peak_max,
+            ml_peak_step=ml_peak_step, dr_min=dr_min, dr_max=dr_max,
+            dr_step=dr_step, dr_default=dr_default, dr_alt=dr_alt,
+            h_max=h_max, h_corr_max=h_corr_max, h_res=h_res,
+            max_weight=max_weight, rmin_obs=rmin_obs,  rmax_obs=rmax_obs,
+            iso0=iso0, correct_iso0=correct_iso0, weight_mem=weight_mem,
+            vpr_theo_dict_mem=vpr_theo_dict_mem, radar_mem_list=radar_mem_list,
+            refl_field=refl_field, corr_refl_field=corr_refl_field,
+            corr_field=corr_field, temp_field=temp_field,
+            iso0_field=iso0_field, temp_ref=temp_ref)
+    else:
+        refl_corr, vpr_corr, vpr_theo_dict, radar_rhi, vpr_info = pyart.correct.correct_vpr(
+            radar, nvalid_min=nvalid_min, angle_min=angle_min,
+            angle_max=angle_max, ml_thickness_min=ml_thickness_min,
+            ml_thickness_max=ml_thickness_max,
+            ml_thickness_step=ml_thickness_step, iso0_max=iso0_max,
+            ml_top_diff_max=ml_top_diff_max, ml_top_step=ml_top_step,
+            ml_peak_min=ml_peak_min, ml_peak_max=ml_peak_max,
+            ml_peak_step=ml_peak_step, dr_min=dr_min, dr_max=dr_max,
+            dr_step=dr_step, dr_default=dr_default, dr_alt=dr_alt,
+            h_max=h_max, h_corr_max=h_corr_max, h_res=h_res,
+            max_weight=max_weight, rmin_obs=rmin_obs, rmax_obs=rmax_obs,
+            iso0=iso0, filter_params=filter_params, weight_mem=weight_mem,
+            vpr_theo_dict_mem=vpr_theo_dict_mem, radar_mem_list=radar_mem_list,
+            refl_field=refl_field, corr_refl_field=corr_refl_field,
+            corr_field=corr_field, temp_field=temp_field,
+            iso0_field=iso0_field, temp_ref=temp_ref)
 
     # prepare for exit
     new_dataset = {'radar_out': deepcopy(radar)}
@@ -1078,6 +1120,7 @@ def process_vpr(procstatus, dscfg, radar_list=None):
     new_dataset['radar_out'].add_field(corr_refl_field, refl_corr)
     new_dataset['radar_out'].add_field(corr_field, vpr_corr)
     new_dataset.update({'vpr_theo_dict': vpr_theo_dict})
+    new_dataset.update({'vpr_info': vpr_info})
     new_dataset.update({'radar_rhi': radar_rhi})
 
     return new_dataset, ind_rad
@@ -1326,14 +1369,14 @@ def process_rainrate(procstatus, dscfg, radar_list=None):
                 hydro_field=hydro_field, rr_field=None,
                 master_field=refl_field, thresh=thresh, thresh_max=True)
         elif refl_field in radar.fields:
-            warn('Unable to compute rainfall rate using hydrometeor ' +
-                 'classification. Missing data. ' +
+            warn('Unable to compute rainfall rate using hydrometeor '
+                 'classification. Missing data. '
                  'A simple Z-R relation will be used instead')
             rain = pyart.retrieve.est_rain_rate_z(
                 radar, alpha=alphazr, beta=betazr, refl_field=refl_field,
                 rr_field=None)
         else:
-            warn('Unable to compute rainfall rate using hydrometeor ' +
+            warn('Unable to compute rainfall rate using hydrometeor '
                  'classification. Missing data.')
             return None, None
     else:
@@ -1388,8 +1431,8 @@ def process_rainfall_accumulation(procstatus, dscfg, radar_list=None):
 
     radarnr, _, datatype, _, _ = get_datatype_fields(dscfg['datatype'][0])
     if datatype != 'RR':
-        warn('Unable to compute rainfall accumulation. Data type: '+datatype +
-             '. Expected RR')
+        warn(f'Unable to compute rainfall accumulation. '
+             f'Data type: {datatype}. Expected RR')
         return None, None
     field_name = get_fieldname_pyart(datatype)
 
@@ -1579,7 +1622,7 @@ def process_bird_density(procstatus, dscfg, radar_list=None):
     radar = radar_list[ind_rad]
 
     if vol_refl_field not in radar.fields:
-        warn('Unable to obtain bird density. Missing field '+vol_refl_field)
+        warn(f'Unable to obtain bird density. Missing field {vol_refl_field}')
         return None, None
 
     sigma_bird = dscfg.get('sigma_bird', 11.)
